@@ -218,12 +218,12 @@ class CGCalendar extends CGExtensions
 
   function GetVersion()
     {
-      return '1.10.0.1';
+      return '1.10.1';
     }
 
   function GetDependencies()
     {
-      return array('CGExtensions'=>'1.29.1');
+      return array('CGExtensions'=>'1.31');
     }
 
   function GetDescription($lang = 'en_US')
@@ -248,7 +248,7 @@ class CGCalendar extends CGExtensions
 
   function MinimumCMSVersion()
     {
-      return '1.10.2';
+      return '1.11.2';
     }
 
   function GetChangeLog()
@@ -539,86 +539,82 @@ class CGCalendar extends CGExtensions
 	$db = $this->GetDb();
 	$sql = 'SELECT category_name FROM '.$this->categories_table_name.'
              WHERE category_id = ?';
-	$name = $db->GetOne($query,array($id));
+	$name = $db->GetOne($sql,array($id));
 	return $name;
   }
 
   function AllowAccess($permission='Modify Calendar')
-    {
-      $access = $this->CheckPermission($permission);
-      if (!$access)  {
-	echo '<p class="error">'.$this->Lang('error_permission',$permission).'</p>';
-	return false;
-      }
-      return true;
-    }
+  {
+	$access = $this->CheckPermission($permission);
+	if (!$access)  {
+	  echo '<p class="error">'.$this->Lang('error_permission',$permission).'</p>';
+	  return false;
+	}
+	return true;
+  }
 
   function LoadAdmin()
-    {
-      if( $this->admin_tools_loaded === false )
-	{
+  {
+	if( $this->admin_tools_loaded === false ) {
 	  require_once('functions.admin_tools.php');
 	}
-    }
+  }
 
   function AdminDisplayCategories($id, &$parameters, $returnid)
-    {
-      $this->LoadAdmin();
-      return calendar_AdminDisplayCategories($this,$id,$parameters,$returnid);
-    }
-
+  {
+	$this->LoadAdmin();
+	return calendar_AdminDisplayCategories($this,$id,$parameters,$returnid);
+  }
 
   function AdminDeleteEvent($id, &$parameters, $returnid)
-    {
-      $this->LoadAdmin();
-      return calendar_AdminDeleteEvent($this,$id,$parameters,$returnid);
-    }
-
+  {
+	$this->LoadAdmin();
+	return calendar_AdminDeleteEvent($this,$id,$parameters,$returnid);
+  }
 
   function GetFields()
-    {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
-      $fields_table_name = $this->fields_table_name;
-      $sql = "SELECT * FROM $fields_table_name ORDER BY field_name";
+  {
+    $db = $this->GetDb(); /* @var $db ADOConnection */
+    $fields_table_name = $this->fields_table_name;
+	$sql = "SELECT * FROM $fields_table_name ORDER BY field_name";
 
-      $result = array();
-      $rs = $db->Execute($sql);
-      if($rs && $rs->RecordCount() > 0) {
-		$result = $rs->GetArray();
-		if( is_array($result) && count($result) ) {
-		  foreach( $result as &$one ) {
-			if( $one['field_extra'] != '' ) {
-			  $one['field_extra'] = unserialize($one['field_extra']);
-			}
+	$result = array();
+	$rs = $db->Execute($sql);
+	if($rs && $rs->RecordCount() > 0) {
+	  $result = $rs->GetArray();
+	  if( is_array($result) && count($result) ) {
+		foreach( $result as &$one ) {
+		  if( $one['field_extra'] != '' ) {
+			$one['field_extra'] = unserialize($one['field_extra']);
 		  }
 		}
 	  }
-      return $result;		
-    }
-
+	}
+	return $result;		
+  }
 
   function AdminDeleteField($field_oldname)
-    {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
-      $fields_table_name = $this->fields_table_name;
-      $event_field_values_table_name = $this->event_field_values_table_name;
+  {
+	$db = $this->GetDb(); /* @var $db ADOConnection */
+	$fields_table_name = $this->fields_table_name;
+	$event_field_values_table_name = $this->event_field_values_table_name;
 	  
-      $sql = "DELETE FROM $$event_field_values_table_name where field_name='$field_oldname'";
-      $db->Execute($sql);
+	$sql = "DELETE FROM $$event_field_values_table_name where field_name='$field_oldname'";
+	$db->Execute($sql);
 		
-      $sql = "DELETE FROM $fields_table_name where field_name='$field_oldname'";
-      $db->Execute($sql);
-    }
+	$sql = "DELETE FROM $fields_table_name where field_name='$field_oldname'";
+	$db->Execute($sql);
+  }
 	
   function AdminAddField($field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
-    {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
-      $sql = 'INSERT INTO ' . $this->fields_table_name . '
-                (field_name,field_type,field_searchable,field_extra)
-              VALUES (?,?,?,?)';
-	  if( $field_extra ) $field_extra = serialize($field_extra);
-      $db->Execute($sql,array($field_newname,$field_type,$field_searchable,$field_extra));
-    }
+  {
+	$db = $this->GetDb(); /* @var $db ADOConnection */
+	$sql = 'INSERT INTO ' . $this->fields_table_name . '
+            (field_name,field_type,field_searchable,field_extra)
+            VALUES (?,?,?,?)';
+	if( $field_extra ) $field_extra = serialize($field_extra);
+	$db->Execute($sql,array($field_newname,$field_type,$field_searchable,$field_extra));
+  }
 	
   function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
     {
