@@ -75,17 +75,16 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
   $events_table_name = $module->events_table_name;
   $first_day_of_week = get_parameter_value($parameters, 'first_day_of_week', 1);
   $pastitems = get_parameter_value($parameters, 'pastitems', 0);
-  $reverse = 'false';
+  $reverse = false;
   $page = get_parameter_value($parameters,'page',1);
-  if( $pastitems )
-    {
-      $expr = '<';
-      $reverse = 'true';
-    }
+  if( $pastitems ) {
+    $expr = '<';
+    $reverse = $true;
+  }
   $return_link = get_parameter_value($parameters, 'return_link', 0);
   $limit = get_parameter_value($parameters, 'limit', 10000);
   $inline = get_parameter_value($parameters,'inline',0);
-  $reverse = get_parameter_value($parameters, 'reverse', 'false');
+  $reverse = cms_to_bool(get_parameter_value($parameters, 'reverse', $reverse));
   $columns=get_parameter_value($parameters, 'columns', '1');
   $columnstyle=get_parameter_value($parameters, 'columnstyle', '1');
   $currentcolumn=get_parameter_value($parameters, 'currentcolumn', '1');
@@ -96,10 +95,10 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
   $sql2 = "SELECT $events_table_name.* FROM $events_table_name";
   if(!empty($category))
     {
-      $txt .= "INNER JOIN $events_to_categories_table_name
-		  ON $events_table_name.event_id = $events_to_categories_table_name.event_id
-	       INNER JOIN $categories_table_name
-	          ON $events_to_categories_table_name.category_id = $categories_table_name.category_id";
+      $txt = "INNER JOIN $events_to_categories_table_name
+	         ON $events_table_name.event_id = $events_to_categories_table_name.event_id
+	      INNER JOIN $categories_table_name
+	         ON $events_to_categories_table_name.category_id = $categories_table_name.category_id";
       $sql2 .= " ".$txt;
     }
 
@@ -135,6 +134,7 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
       $tmp = array();
       foreach( $cats as $cat )
 	{
+	  $cat = trim($cat);
 	  $tmp[] = "($categories_table_name.category_name LIKE '$cat')";
 	}
       $txt = '('.implode(' OR ',$tmp).')';
@@ -205,14 +205,12 @@ function DisplayUpcomingList(&$module, $id, &$parameters, $returnid)
 	  $parms['display'] = 'event';
 	  $parms['detailpage'] = $detailpage;
 	  $parms['return_id'] = $returnid;
-	  if( isset($parameters['eventtemplate']) )
-	    {
-	      $parms['eventtemplate'] = $parameters['eventtemplate'];
-	    }
-	  if( isset($parameters['lang']) )
-	    {
-	      $parms['lang'] = $parameters['lang'];
-	    }
+	  if( isset($parameters['eventtemplate']) ) {
+	    $parms['eventtemplate'] = $parameters['eventtemplate'];
+	  }
+	  if( isset($parameters['lang']) ) {
+	    $parms['lang'] = $parameters['lang'];
+	  }
 	  $url = $module->CreateLink($id, 'default', $destpage, $contents='', 
 				     $parms,
 				     '', true, '', '', '', 
