@@ -74,8 +74,8 @@ function DisplayYearList(&$module, $id, &$parameters, $returnid)
 	$return_link = get_parameter_value($parameters, 'return_link', 0);
 	$limit = get_parameter_value($parameters, 'limit', -1);
 
-	$reverse = get_parameter_value($parameters, 'reverse', 'false');
-	$sorting = ($reverse == 'true' ? 'DESC' : 'ASC');
+	$reverse = cms_to_bool(get_parameter_value($parameters, 'reverse', false));
+	$sorting = ($reverse == true ? 'DESC' : 'ASC');
 
 	$use_session = get_parameter_value($parameters, 'use_session', true);
 	if($use_session)
@@ -163,14 +163,12 @@ function DisplayYearList(&$module, $id, &$parameters, $returnid)
 		        $parms = array();
 		        $parms['event_id'] = $row['event_id'];
 			$parms['display'] = 'event';
-			if( isset($parameters['eventtemplate']) )
-			  {
-			    $parms['eventtemplate'] = $parameters['eventtemplate'];
-			  }
-			if( isset($parameters['lang']) )
-			  {
-			    $parms['lang'] = $parameters['lang'];
-			  }
+			if( isset($parameters['eventtemplate']) ) {
+			  $parms['eventtemplate'] = $parameters['eventtemplate'];
+			}
+			if( isset($parameters['lang']) ) {
+			  $parms['lang'] = $parameters['lang'];
+			}
 			$url = $module->CreateLink($id, 'default', $destpage, $contents='', 
 						   $parms,  '', true, '', '', $prettyurl);
 			$row['url'] = $url;
@@ -219,9 +217,9 @@ function DisplayYearList(&$module, $id, &$parameters, $returnid)
 	  {
 	    $parms['lang'] = $parameters['lang'];
 	  }
-	$parms['year'] = ($reverse == 'false')?$next_year['year']:$prev_year['year'];
+	$parms['year'] = ($reverse == false)?$next_year['year']:$prev_year['year'];
 	$navigation['next'] = $module->CreateURL($id, 'default', $returnid, $parms, $inline );
-	$parms['year'] = ($reverse == 'false')?$prev_year['year']:$next_year['year'];
+	$parms['year'] = ($reverse == false)?$prev_year['year']:$next_year['year'];
 	$navigation['prev'] = $module->CreateURL($id, 'default', $returnid, $parms, $inline );
 
 	$day_names = $module->GetDayNames();
