@@ -426,193 +426,4 @@ $lang['cal_recur_until'] = 'R&eacute;p&egrave;te jusqu&#039;&agrave;';
 $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
 <code>Auteur : {$event.authorname}</code>
 ';
-$lang['cal_help'] = '		<h3>Notice:</h3>
-		<p>Le module Calendrier (CG) Version 1.0  est un fork du module de Calendrier classique, mais Calendrier  (CG) n&#039;est aucunement compatible avec Calendrier.
-		<h3>Que fait ce module ?</h3>
-		<p>Ce module affiche des &eacute;v&eacute;nements sur vos pages. D&egrave;s que le module est install&eacute;, une page de gestion des &eacute;v&eacute;nements est ajout&eacute;e au menu d&#039;administration qui vous permettra de g&eacute;rer des &eacute;v&eacute;nements.</p>
-		<h3>S&eacute;curit&eacute;</h3>
-		<p>L&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Modify Calendar&#039; pour pouvoir ajouter, &eacute;diter ou supprimer des &eacute;v&eacute;nements.</p>
-		<h3>Comment l&#039;utiliser?</h3>
-		<ol>
-		  <li>Le module calendrier est utilis&eacute; en conjonction avec le tag cms_module. Veuillez vous assurer que le tag n&#039;est pas inclus dans les balises &amp;lt;pre&amp;gt; ... &amp;lt;/pre&amp;gt; Vous aurez besoin d&#039;afficher le code source pour cela. Cela ins&eacute;rera votre module dans votre gabarit ou votre page o&ugrave; vous le d&eacute;sirez, et y affichera le calendrier.  Exemple de syntaxe:<br />
-		<tt>{cms_module module=&#039;CGCalendar&#039;}</tt><br />
-		  <li>&Eacute;ditez la feuille de style d&#039;exemple qui a &eacute;t&eacute; ins&eacute;r&eacute;e dans la liste de vos feuilles de style.</li>
-		  <li>Associez cette feuille de style au gabarit que vous utilisez pour les pages de calendrier.</li>
-		</ol>
-<br />
-<p><b>Pour attacher la feuille de style &agrave; votre gabarit :</b></p>
-<ol>
-<li>Allez &agrave;  &quot;Disposition -> Gabarits&quot;.</li>
-<li>Cliquez l&#039;ic&ocirc;ne CSS (Attacher une feuille de style au gabarit) &agrave; droite de votre gabarit.</li>
-<li>Choisissez &quot;CGCalendrier : exemple de CSS&quot; dans le menu d&eacute;roulant.</li>
-<li>Cliquez le bouton &quot;Ajouter une nouvelle feuille de style&quot;.</li>
-</ol>
-
-</p>
-		<h3>Local</h3>
-		<p>Notez que vous pouvez changer la langue d&#039;un calendrier affich&eacute; sur une page sp&eacute;cifique en ajoutant 
-		lang=&quot;xx_XX&quot; au {cms_module module=&quot;CGCalendar&quot;}. Par exemple: {cms_module module=&quot;CGCalendar&quot; lang=&quot;de_DE&quot;}</p>
-
-		<h3>Quels sont les param&egrave;tres possibles ?</h3>
-		<table border=0 cellpadding=3 cellspacing=0>
-		<tr>
-			<td>action</td>
-			<td>
-                &quot;default&quot; - indique d&#039;utiliser l&#039;action par d&eacute;faut, fonctionne en conjonction avec le param&egrave;tre &quot;display&quot; ci-dessous.<br/>
-                &quot;search&quot; - affiche un formulaire de recherche avanc&eacute;e d&#039;&eacute;v&eacute;nement du calendrier.
-                &quot;myevents&quot; - affiche une liste contenant tous les &eacute;v&eacute;nements d&#039;un utilisateur et permet d&#039;ajouter, &eacute;diter ou supprimer ces &eacute;v&eacute;nements.
-               &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
-		</td>
-		</tr>
-
-			<tr>
-			<td>display (Affichage)</td>
-			<td>Valeur accept&eacute;es:<br>
-&quot;calendar&quot; (calendrier) - affiche les &eacute;v&eacute;nements pour le mois en cours dans une grille traditionnelle. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
-&quot;event&quot; (&eacute;v&eacute;nement) - affiche les d&eacute;tails d&#039;un &eacute;v&eacute;nement en particulier. Pour l&#039;utiliser, le param&egrave;tre event_id doit &ecirc;tre sp&eacute;cifi&eacute;.<br />
-&quot;list&quot; (liste) - affiche les &eacute;v&eacute;nements pour le mois en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
-&quot;yearlist&quot; (liste annuelle) - affiche les &eacute;v&eacute;nements pour l&#039;ann&eacute;e en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent &agrave; l&#039;ann&eacute;e concern&eacute;e.<br />
-&quot;pastlist&quot; (liste des &eacute;v&eacute;nements pass&eacute;s) - affiche tous les &eacute;v&eacute;nements pass&eacute;s. Pas de liens suivant-pr&eacute;c&eacute;dent.<br />
-&quot;upcominglist&quot; (liste des &eacute;v&eacute;nements &agrave; venir) - affiche tous les &eacute;v&eacute;nements &agrave; venir. Pas de liens suivant-pr&eacute;c&eacute;dent.<br />
-Valeur par d&eacute;faut : &quot;calendar&quot; <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>category (Cat&eacute;gorie)</td>
-			<td>Affiche seulement les &eacute;v&eacute;nements de cette cat&eacute;gorie. Laisser ce param&egrave;tre vide pour afficher tous les &eacute;v&eacute;nements. Notez que vous pouvez d&eacute;finir ici plusieurs cat&eacute;gories en les s&eacute;parant par une virgule. <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>month (Mois)</td>
-			<td>Affiche les &eacute;v&eacute;nements du mois sp&eacute;cifi&eacute;. Si l&#039;ann&eacute;e n&#039;est pas d&eacute;finie, l&#039;ann&eacute;e en cours est utilis&eacute;e. Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot; ou &quot;calendar&quot;. <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>year (Ann&eacute;e)</td>
-			<td>Affiche les &eacute;v&eacute;nements de l&#039;ann&eacute;e sp&eacute;cifi&eacute;e. 
-Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot; ou &quot;calendar&quot;. <em>(optionel)</em></td>
-		</tr>
-		<tr>
-
- <tr>
-     <td>limit</td>
-     <td>Param&egrave;tre le nombre maximum d&#039;&eacute;v&egrave;nements &agrave; afficher. Cette option ne fonctionne uniquement si &quot;display&quot; est param&eacute;tr&eacute; &agrave; &quot;list&quot;, &quot;pastlist&quot; ou &quot;upcominglist&quot;. <em>(optional)</em></td>
-  </tr>
-
-		<tr>
-			<td>first_day_of_week (Premier jour de la semaine)</td>
-			<td>D&eacute;fini le premier jour de la semaine, en chiffre de 0 &agrave; 6 (0 = Dimanche). Valeur par d&eacute;faut : 1 (Lundi).
-Cette option ne fonctionne que si &quot;display&quot; est valoris&eacute; &agrave; &quot;calendar&quot;.<em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>use_session</td>
-			<td>Utilise des variables de session pour stocker les sp&eacute;cifications du calendrier. Ceci permet au calendrier de garder ses param&egrave;tres lors de la navigation sur plusieurs pages et lors de l&#039;affichage de plusieurs mois. Dans le formulaire de recherche, cela permet d&#039;enregistrer les param&egrave;tres de recherche jusqu&#039;&agrave; ce que le navigateur soit r&eacute;initialis&eacute;. La valeur par d&eacute;faut est &quot;false&quot; (faux). Si sp&eacute;cifi&eacute;, la valeur doit contenir un identifiant unique pour cette instance de calendrier. Cette fonction ne fonctionne que si &quot;display&quot; est valoris&eacute; &agrave; &quot;calendar&quot; ou &quot;list&quot;, ou si &quot;action&quot; est valoris&eacute; &agrave; &quot;search&quot;.<em>(optional)</em></td>
-		</tr>
-		<tr>
-			<td>inline</td>
-			<td>D&eacute;finir en 1 pour afficher tous les liens aux &eacute;v&eacute;nements en mode inline (ils remplaceront le contenu de la page).<br />
-Valeur par d&eacute;faut : 0 <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>reverse</td>
-			<td>Valoriser &agrave; &quot;true&quot; (vrai) pour afficher les &eacute;v&eacute;nements dans l&#039;ordre chronologique inverse. Applicable aux affichages &quot;list&quot;, &quot;pastlist&quot; et &quot;upcominglist&quot;. Valeur par d&eacute;faut : &quot;false&quot; (faux). Pour l&#039;option &quot;pastlist&quot;, reverse=true est suppos&eacute;.<em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>detailpage=&quot;pagealias&quot;</td>
-			<td>Page dans laquelle afficher les d&eacute;tails des &eacute;v&eacute;nements. Ceci peut soit &ecirc;tre soit un alias de page soit un ID de page. Utile pour permettre aux d&eacute;tails d&#039;&ecirc;tre affich&eacute;s dans un gabarit diff&eacute;rent du sommaire.<br />
-Comportement par d&eacute;faut : affichage dans la page courante <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>columns</td>
-			<td>Le calendrier affichera uniquement une suite d&#039;&eacute;v&eacute;nements &agrave; afficher en colonnes. Valeurs possible 1 ou 2. Valeur par d&eacute;faut : 1. Impl&eacute;ment&eacute; uniquement pour les affichages &quot;upcominglist&quot; et &quot;pastlist&quot;.<em>(optionel)</em></td>
-		</tr>
-	  <tr>
-			<td>columnstyle</td>
-			<td>Si le param&egrave;tre columns=2, ce param&egrave;tre d&eacute;fini si l&#039;ordre des &eacute;v&eacute;nements en colonne doit &ecirc;tre affich&eacute; horizontalement (0) ou verticalement (1). Valeur par d&eacute;faut : 1 <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>currentcolumn</td>
-			<td>Si le param&egrave;tre columns=2, ce param&egrave;tre indique si le calendrier doit afficher le contenu de la colonne 1 ou 2. Valeur possible 1 ou 2.<br />
-Valeur par d&eacute;faut : 1  <em>(optional)</em></td>
-		</tr>
-		<tr>
-			<td>event_id</td>
-			<td>Utilis&eacute; uniquement avec le mode d&#039;affichage &quot;event&quot; Permet d&#039;afficher les informations relatives uniquement &agrave; un &eacute;v&eacute;nement sp&eacute;cifique. </td>
-		</tr>
-		<tr>
-			<td>limit</td>
-			<td>D&eacute;fini le nombre maximal d&#039;&eacute;v&eacute;nements &agrave; afficher. Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot;, &quot;pastlist&quot; ou &quot;upcominglist&quot; et permet de g&eacute;rer la pagination. <em>(optionel)</em></td>
-		</tr>
-		<tr>
-			<td>calendartemplate</td>
-			<td>Sp&eacute;cifie un gabarit particulier &agrave; utiliser pour l&#039;affichage en mode &quot;calendar&quot; uniquement.  <em>(optionel)</em><br />
-Par exemple, si vous avez un gabarit nomm&eacute; &quot;mon-gabarit-calendrier&quot;, alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;calendar&quot; calendartemplate=&quot;mon-gabarit-calendrier&quot;}</code></td>
-		</tr>
-  <tr>
-     <td>eventtemplate</td>
-     <td>Utilis&eacute; en mode d&#039;affiche &quot;event&quot;. Vous pouvez &eacute;galement d&eacute;finir ce param&egrave;tre sur tous les appels au module Calendar, Ce param&egrave;tre vous permet de sp&eacute;cifier un gabarit diff&eacute;rent du gabarit par d&eacute;faut pour les &eacute;v&egrave;nements.</td>
-  </tr>
-
-		<tr>
-			<td>listtemplate</td>
-			<td>Sp&eacute;cifie le gabarit &agrave; utiliser pour l&#039;affichage &quot;list&quot;. <em>(optionel)</em><br/>
-Par exemple, si vous avez un gabarit nomm&eacute; &quot;blog-post-month-archive-list&quot;, alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;list&quot; reverse=&quot;true&quot; listtemplate=&quot;blog-post-month-archive-list&quot;}</code></td>
-		</tr>
-		<tr>
-			<td>upcominglisttemplate</td>
-			<td>Sp&eacute;cifie le gabarit &agrave; utiliser pour l&#039;affichage &quot;pastlist&quot; (liste des &eacute;v&eacute;nements pass&eacute;s) ou &quot;upcominglist&quot; (liste des &eacute;v&eacute;nements &agrave; venir). <em>(optionel)</em><br />
-Par exemple, si vous avez un gabarit nomm&eacute; &quot;blog-post-list-with-content&quot; et que vous d&eacute;sirez afficher les 50 derniers &eacute;v&eacute;nements de la cat&eacute;gorie &quot;g&eacute;n&eacute;rale&quot;,  alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;pastlist&quot; category=&quot;General&quot; upcominglisttemplate=&quot;blog-post-list-with-content&quot; limit=&quot;50&quot;}
-</code></td>
-		</tr>
-	  <tr>
-     <td>unique_only</td>
-     <td>Utilis&eacute; en mode d&#039;affichage &quot;upcominglist&quot; et avec l&#039;action = &quot;search&quot;, Ce param&egrave;tre vous permet de d&eacute;finir qu&#039;un seul &eacute;v&eacute;nement d&#039;un certain type doit &ecirc;tre retourn&eacute;.
-  </tr>
-
-		</table>
-
-		<h3>Gabarits</h3>
-		<p>Les quatre types d&#039;affichage sont contr&ocirc;l&eacute;s par des gabarits qui peuvent &ecirc;tres chang&eacute;s dans l&#039;administration. Si vous voulez r&eacute;initialiser un gabarit &agrave; ses donn&eacute;es par d&eacute;faut, effacez-en compl&egrave;tement le contenu dans l&#039;administration et il sera r&eacute;initialis&eacute; lors du prochain affichage de ce calendrier sur la page.</p>
-
-		<h3>Exemple de styles CSS</h3>
-		<p>Un exemple de CSS pour afficher correctement le calendrier a &eacute;t&eacute; ajout&eacute; &agrave; la liste de vos feuilles de style. Pour le voir en action&nbsp;:
-		<pre style=&quot;font-size: 12px&quot;>{cms_module module=&#039;CGCalendar&#039; table_id=&#039;big&#039;}</pre></p>
-
-		<h3>Champs personnalis&eacute;s</h3>
-		<p>Il est possible de d&eacute;finir des champs personnalis&eacute;s &agrave; associer avec chaque &eacute;v&eacute;nement au moyen de l&#039;onglet &quot;Champs&quot; dans le panneau d&#039;administration du module. Une fois qu&#039;un ou plusieurs champ(s) aient &eacute;t&eacute; d&eacute;finis, les valeurs de ce champ pour chaque &eacute;v&eacute;nement peuvent &ecirc;tre d&eacute;finies au moyen de l&#039;onglet &quot;&Eacute;v&eacute;nements&quot; dans l&#039;administration. Les valeurs de ces champs peuvent &ecirc;tre obtenue avec l&#039;utilisation d&#039;un gabarit ayant la syntaxe event.fields.fieldname. Astuce - ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es qui sont pass&eacute;es au gabarit.</p>
-
-	<h3>Exemples</h3>
-		<h4>Exemple autoriser les commentaires sur les &eacute;v&eacute;nements du calendrier</h4>
-				<p>Installez le module Commentaires et ins&eacute;rez ceci dans votre le &quot;gabarit d&#039;&eacute;v&eacute;nement&quot; de votre calendrier&amp;nssp;:</p>
-		<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
-<p>Conseil : ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es disponibles pass&eacute;es au gabarit</p>
-
-<h3>Support</h3>
-<p>Ce module n&#039;inclu aucun support commercial. Cependant, il y a un certain nombre de ressources disponibles pour vous aider :</p>
-<ul>
-<li>Des discussion sur ce module peuvent &ecirc;tre trouv&eacute;es sur <a href="http://forum.cmsmadesimple.org">les forums CMS Made Simple</a>.</li>
-<li>L&#039;auteur, calguy1000, peut facilement &ecirc;tre contact&eacute; sur <a href="irc://irc.freenode.net/#cms">le canal IRC relatif aux CMS</a>.</li>
-<li>Enfin, vous pouvez &eacute;ventuellement contacter l&#039;auteur directement par mail.</li>  
-</ul>
-<h3>Copyright et Licence</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
-';
-$lang['utma'] = '156861353.748041509.1335632272.1335632272.1335774814.2';
-$lang['utmz'] = '156861353.1335632272.1.1.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1335774814';
-?>
\ No newline at end of file
+?>
